﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2015 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion


using HeuristicLab.Clients.Hive.WebJobManager.Controllers;
using HeuristicLab.Clients.Hive.WebJobManager.Services;
using HeuristicLab.Clients.Hive.WebJobManager.Services.Imports;
using HeuristicLab.Clients.Hive.WebJobManager.ViewModels.User;
using Microsoft.AspNetCore.SignalR;
using System;

namespace HeuristicLab.Clients.Hive.WebJobManager.Hubs
{
    /// <summary>
    /// Small SignalR hub to change the password from a user
    /// </summary>
    public class UserInfoHub: Hub
    {
        private WebLoginService weblog;
        private Guid userId;
        private AccessAdministrationClient aac;
        /// <summary>
        /// Loads required services
        /// </summary>
        private void loader()
        {
            weblog = WebLoginService.Instance;
            string uid = Context.QueryString["userid"];
            if (uid == null || uid == "" || Guid.Parse(uid) == Guid.Empty)
            {
                userId = Guid.Empty;
            }
            else
            {
                userId = Guid.Parse(uid);
                aac = weblog.getAccessAdminClient(userId);
            }
        }
        /// <summary>
        /// Request to change pass 
        /// </summary>
        /// <param name="user">User id</param>
        public void resetPassword(string user)
        {
            loader();
            Guid userid = Guid.Parse(user);
            Access.User u = new UserViewModel(aac, weblog.getCurrentUser(userId)).refreshUsers().getUserById(userid);
            var pass = aac.resetPassword(userid);
            UserController.sendPassmail(u, pass);//Send mail + show pass            
            Clients.Caller.showNewPass(pass);
        }
    }
}
